@@ -19,15 +19,19 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
         title=f"Dependency Scan Results ({project_type})",
         box=box.DOUBLE_EDGE,
         header_style="bold magenta",
+        show_lines=True,
     )
+    ids_seen = {}
     required_pkgs = scoped_pkgs.get("required", [])
     optional_pkgs = scoped_pkgs.get("optional", [])
     pkg_attention_count = 0
+    has_poc_count = 0
+    has_exploit_count = 0
     fix_version_count = 0
     for h in [
         "Id",
         "Package",
-        "Used?",
+        "Insights",
         "Version",
         "Fix Version",
         "Severity",
@@ -36,14 +40,7 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
         justify = "left"
         if h == "Score":
             justify = "right"
-        width = None
-        if h == "Id":
-            width = 20
-        elif h == "Used?" or h == "Fix Version":
-            width = 10
-        elif h == "Description":
-            width = 58
-        table.add_column(header=h, justify=justify, width=width, no_wrap=False)
+        table.add_column(header=h, justify=justify, no_wrap=False)
     for res in results:
         vuln_occ_dict = res.to_dict()
         id = vuln_occ_dict.get("id")
@@ -59,8 +56,12 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
             )
         # De-alias package names
         full_pkg = pkg_aliases.get(full_pkg, full_pkg)
+        if ids_seen.get(id + full_pkg):
+            continue
+        ids_seen[id + full_pkg] = True
         fixed_location = sug_version_dict.get(full_pkg, package_issue.fixed_location)
         package_usage = "N/A"
+        insights = []
         package_name_style = ""
         id_style = ""
         pkg_severity = vuln_occ_dict.get("severity")
@@ -73,12 +74,33 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
             if fixed_location:
                 fix_version_count = fix_version_count + 1
         if is_required:
-            package_usage = "[bright_green][bold]Yes"
+            package_usage = ":direct_hit: Direct usage"
             package_name_style = "[bold]"
         elif full_pkg in optional_pkgs or project_type_pkg in optional_pkgs:
-            package_usage = "[magenta]No"
+            package_usage = (
+                "[spring_green4]:information: Indirect dependency[/spring_green4]"
+            )
             package_name_style = "[italic]"
         package = full_pkg.split(":")[-1]
+        clinks = classify_links(
+            id,
+            full_pkg,
+            vuln_occ_dict.get("type"),
+            package_issue.affected_location.version,
+            vuln_occ_dict.get("related_urls"),
+        )
+        if package_usage != "N/A":
+            insights.append(package_usage)
+        if clinks.get("poc") or clinks.get("Bug Bounty"):
+            insights.append("[yellow]:notebook_with_decorative_cover: Has PoC[/yellow]")
+            has_poc_count = has_poc_count + 1
+        if clinks.get("vendor"):
+            insights.append(":receipt: Vendor Confirmed")
+        if clinks.get("exploit"):
+            insights.append(
+                "[bright_red]:exclamation_mark: Known Exploits[/bright_red]"
+            )
+            has_exploit_count = has_exploit_count + 1
         table.add_row(
             "{}{}{}{}".format(
                 id_style,
@@ -87,7 +109,7 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
                 id,
             ),
             "{}{}".format(package_name_style, package),
-            package_usage,
+            "\n".join(insights),
             package_issue.affected_location.version,
             fixed_location,
             "{}{}".format(
@@ -100,14 +122,28 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
             ),
         )
     console.print(table)
-    if scoped_pkgs:
-        if pkg_attention_count:
-            rmessage = f":heavy_exclamation_mark: [magenta]{pkg_attention_count}[/magenta] out of {len(results)} vulnerabilities requires your attention."
+    if scoped_pkgs or has_exploit_count:
+        if not pkg_attention_count and has_exploit_count:
+            rmessage = f":point_right: [magenta]{has_exploit_count}[/magenta] out of {len(results)} vulnerabilities have known exploits and requires your [magenta]immediate[/magenta] attention."
+            rmessage += f"\nAdditional workarounds and configuration changes might be required to remediate these vulnerabilities."
+            if not scoped_pkgs:
+                rmessage += f"\nNOTE: Package usage analysis was not performed for this project."
+            console.print(
+                Panel(
+                    rmessage,
+                    title="Recommendation",
+                    expand=False,
+                )
+            )
+        elif pkg_attention_count:
+            rmessage = f":point_right: [magenta]{pkg_attention_count}[/magenta] out of {len(results)} vulnerabilities requires your attention."
+            if has_exploit_count:
+                rmessage += f"\nPrioritize the [magenta]{has_exploit_count}[/magenta] vulnerabilities with known exploits."
             if fix_version_count:
                 if fix_version_count == pkg_attention_count:
                     rmessage += "\n:white_heavy_check_mark: You can update [bright_green]all[/bright_green] the packages using the mentioned fix version to remediate."
                 else:
-                    rmessage += f"\nYou can remediate [bright_green]{fix_version_count}[/bright_green] {'vulnerability' if fix_version_count == 1 else 'vulnerabilities'} by updating the packages using the fix version :thumbsup:."
+                    rmessage += f"\nYou can remediate [bright_green]{fix_version_count}[/bright_green] {'vulnerability' if fix_version_count == 1 else 'vulnerabilities'} by updating the packages using the fix version :thumbsup:"
             console.print(
                 Panel(
                     rmessage,
@@ -123,6 +159,14 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_p
                     expand=False,
                 )
             )
+    else:
+        console.print(
+            Panel(
+                ":white_check_mark: No package requires immediate attention.",
+                title="Recommendation",
+                expand=False,
+            )
+        )
 
 
 def analyse(project_type, results):
@@ -145,6 +189,7 @@ def jsonl_report(
     :param pkg_aliases: Package alias
     :param out_file_name: Output filename
     """
+    ids_seen = {}
     required_pkgs = scoped_pkgs.get("required", [])
     optional_pkgs = scoped_pkgs.get("optional", [])
     excluded_pkgs = scoped_pkgs.get("excluded", [])
@@ -161,6 +206,9 @@ def jsonl_report(
                 )
             # De-alias package names
             full_pkg = pkg_aliases.get(full_pkg, full_pkg)
+            if ids_seen.get(id + full_pkg):
+                continue
+            ids_seen[id + full_pkg] = True
             project_type_pkg = "{}:{}".format(
                 project_type, package_issue.affected_location.package
             )
@@ -296,18 +344,23 @@ def analyse_licenses(project_type, licenses_results, license_report_file=None):
                 table.add_row(*data)
                 report_data.append(dict(zip(headers, data)))
             elif lic["condition_flag"]:
+                conditions_str = ", ".join(lic["conditions"])
+                if "http" not in conditions_str:
+                    conditions_str = (
+                        conditions_str.replace("--", " for ").replace("-", " ").title()
+                    )
                 data = [
                     *pkg_ver,
                     "{}{}".format(
                         "[cyan]"
-                        if "GPL" in lic["spdx-id"] or "CC-BY-" in lic["spdx-id"]
+                        if "GPL" in lic["spdx-id"]
+                        or "CC-BY-" in lic["spdx-id"]
+                        or "Facebook" in lic["spdx-id"]
+                        or "WTFPL" in lic["spdx-id"]
                         else "",
                         lic["spdx-id"],
                     ),
-                    ", ".join(lic["conditions"])
-                    .replace("--", " for ")
-                    .replace("-", " ")
-                    .title(),
+                    conditions_str,
                 ]
                 table.add_row(*data)
                 report_data.append(dict(zip(headers, data)))
@@ -353,3 +406,42 @@ def suggest_version(results, pkg_aliases={}):
             if mversion:
                 sug_map[k] = mversion
     return sug_map
+
+
+def classify_links(id, package, package_type, version, related_urls):
+    """Method to classify and identify well-known links"""
+    clinks = {}
+    for rurl in related_urls:
+        if "github.com" in rurl and "/pull" in rurl:
+            clinks["GitHub PR"] = rurl
+        elif "github.com" in rurl and "/issues" in rurl:
+            clinks["GitHub Issue"] = rurl
+        elif "poc" in rurl:
+            clinks["poc"] = rurl
+        elif "apache.org" in rurl and "security" in rurl:
+            clinks["Apache Security"] = rurl
+            clinks["vendor"] = rurl
+        elif "debian.org" in rurl and "security" in rurl:
+            clinks["Debian Security"] = rurl
+            clinks["vendor"] = rurl
+        elif "rubyonrails-security" in rurl:
+            clinks["Ruby Security"] = rurl
+            clinks["vendor"] = rurl
+        elif "redhat.com" in rurl or "oracle.com" in rurl:
+            clinks["vendor"] = rurl
+        elif "openwall.com" in rurl or "oss-security" in rurl:
+            clinks["Mailing List"] = rurl
+            clinks["vendor"] = rurl
+        elif (
+            "exploit-db" in rurl
+            or "exploit-database" in rurl
+            or "seebug.org" in rurl
+            or "seclists.org" in rurl
+            or "nu11secur1ty" in rurl
+        ):
+            clinks["exploit"] = rurl
+        elif "github.com/advisories" in rurl:
+            clinks["GitHub Advisory"] = rurl
+        elif "hackerone" in rurl or "bugcrowd" in rurl or "bug-bounty" in rurl:
+            clinks["Bug Bounty"] = rurl
+    return clinks
