@@ -10,6 +10,16 @@ license_data_dir = join(
     "_licenses",
 )
 
+spdx_license_list = join(
+    dirname(realpath(__file__)),
+    "..",
+    "..",
+    "vendor",
+    "spdx",
+    "json",
+    "licenses.json",
+)
+
 # CPE Vendor aliases
 vendor_alias = {
     "org.apache.tomcat.embed": "apache",
@@ -43,6 +53,8 @@ vendor_alias = {
     "tensorflow": "google",
     "ansible": "redhat",
     "io.springfox": "smartbear",
+    "log4net": "apache",
+    "github": "github actions",
 }
 
 # Package aliases
@@ -108,6 +120,9 @@ package_alias = {
     "hibernate-core": "hibernate_orm",
     "json-smart": "json-smart-v2",
     "ojdbc7": "jdbc",
+    "System.Text": ".net",
+    "Microsoft.IdentityModel.Clients.ActiveDirectory": "active_directory_authentication_library",
+    "starkbank_ecdsa": "ecdsa-elixir",
 }
 
 # Default ignore list
@@ -155,11 +170,18 @@ LANG_PKG_TYPES = {
     "nodejs": "npm",
     "go": "golang",
     "golang": "golang",
-    "ruby": "rubygems",
+    "ruby": "gem",
     "php": "composer",
     "dotnet": "nuget",
     "csharp": "nuget",
-    "rust": "crates",
+    "rust": "cargo",
+    "dart": "pub",
+    "cpp": "conan",
+    "clojure": "clojars",
+    "haskell": "hackage",
+    "elixir": "hex",
+    "github actions": "github",
+    "github": "github",
 }
 
 
