@@ -40,8 +40,13 @@ def create_pkg_variations(pkg_dict):
     vendor = pkg_dict.get("vendor")
     name = pkg_dict.get("name")
     purl = pkg_dict.get("purl", "")
+    if purl:
+        tmpParts = purl.split(":")
+        if tmpParts and len(tmpParts) > 1:
+            vendor_aliases.add(tmpParts[1])
     if vendor:
         vendor_aliases.add(vendor)
+        vendor_aliases.add(vendor.lower())
         if (
             vendor.startswith("org.")
             or vendor.startswith("io.")
@@ -58,13 +63,13 @@ def create_pkg_variations(pkg_dict):
         vendor_aliases.add(name)
     if purl.startswith("pkg:golang") and not name.startswith("go"):
         # Ignore third party alternatives for builtins
-        if "golang" not in vendor and name not in ["net", "crypto", "http"]:
+        if "golang" not in vendor and name not in ["net", "crypto", "http", "text"]:
             vendor_aliases.add("golang")
     if not purl.startswith("pkg:golang"):
         vendor_aliases.add("get" + name)
         vendor_aliases.add(name + "_project")
     for k, v in config.vendor_alias.items():
-        if vendor.startswith(k) or k.startswith(vendor):
+        if vendor and (vendor.startswith(k) or k.startswith(vendor)):
             vendor_aliases.add(k)
             vendor_aliases.add(v)
         elif name == k:
@@ -82,17 +87,40 @@ def create_pkg_variations(pkg_dict):
         vendor_aliases.add("python")
         vendor_aliases.add("python-" + name)
         vendor_aliases.add(name + "project")
-    elif purl.startswith("pkg:npm") and not name.startswith("node-"):
-        name_aliases.add("node-" + name)
+    elif purl.startswith("pkg:npm"):
+        if not name.startswith("node-"):
+            name_aliases.add("node-" + name)
+        # pg-promise CVE is filed as pg
+        if name.endswith("-promise"):
+            name_aliases.add(name.replace("-promise", ""))
     elif purl.startswith("pkg:crates") and not name.startswith("rust-"):
         name_aliases.add("rust-" + name)
     elif purl.startswith("pkg:composer") and not name.startswith("php-"):
         name_aliases.add("php-" + name)
     elif purl.startswith("pkg:nuget"):
         vendor_aliases.add("nuget")
-    elif purl.startswith("pkg:rubygems"):
+        name_parts = name.split(".")
+        vendor_aliases.add(name_parts[0])
+        vendor_aliases.add(name_parts[0].lower())
+        # We dont want this to match microsoft windows
+        if "windows" not in name_parts[-1].lower():
+            name_aliases.add(name_parts[-1])
+            name_aliases.add(name_parts[-1].lower())
+        if name.lower().startswith("system"):
+            vendor_aliases.add("microsoft")
+    elif purl.startswith("pkg:gem") or purl.startswith("pkg:rubygems"):
+        vendor_aliases.add("gem")
         vendor_aliases.add("rubygems")
         vendor_aliases.add("rubyonrails")
+    elif purl.startswith("pkg:hex") or purl.startswith("pkg:elixir"):
+        vendor_aliases.add("hex")
+        vendor_aliases.add("elixir")
+    elif purl.startswith("pkg:pub") or purl.startswith("pkg:dart"):
+        vendor_aliases.add("pub")
+        vendor_aliases.add("dart")
+    elif purl.startswith("pkg:github"):
+        vendor_aliases.add("github actions")
+        name_aliases.add(f"{vendor}/{name}")
     for suffix in COMMON_SUFFIXES:
         if name.endswith(suffix):
             name_aliases.add(name.replace(suffix, ""))
